@@ -107,15 +107,13 @@ class EmergeCommand(CommandExecutor):
         self.child = None
         self.packages = packages
         self.params = self.default_params + extra_params
-        wrong_default_opts = ("--columns","--ask ", "--ask=")
         if emerge_default_opts is None:
             default_env = {'CLEAN_DELAY': '0'}
         else:
             default_env = {
                 'CLEAN_DELAY': '0',
-                'EMERGE_DEFAULT_OPTS': " ".join(filter(
-                    lambda x: not any(y in x for y in wrong_default_opts),
-                    emerge_default_opts))
+                'EMERGE_DEFAULT_OPTS': re.sub(r'(?:^|\s)(--columns)(?=\s|$)','',
+                    emerge_default_opts)
             }
         default_env.update(os.environ)
         self.env = env or default_env
