@@ -175,6 +175,8 @@ class Update(object):
         self.clVars.Write('cl_update_autocheck_interval', interval, True)
         self.clVars.Write('cl_update_other_set', onoff(update_other), True)
         self.clVars.Write('cl_update_cleanpkg_set', onoff(cleanpkg), True)
+        if not status:
+            UpdateInfo.set_update_ready(False)
         return True
 
     def checkSchedule(self, interval, status):
@@ -284,7 +286,7 @@ class Update(object):
                 except OSError as e:
                     raise UpdateError(_("Failed to modify the "
                                         "{repname} repository").format(
-                        repname=repname)+":"+str(e))
+                        repname=repname)+_(": ")+str(e))
                 finally:
                     if path.exists(rpath_new):
                         removeDir(rpath_new)
@@ -404,7 +406,7 @@ class Update(object):
         cpu_num = self.clVars.Get('hr_cpu_num')
         if repname in OverlayOwnCache():
             self.printWARNING(
-                _("Repository %s has own cache") % repname.capitalize())
+                _("Repository %s has its own cache") % repname.capitalize())
         else:
             self.startTask(_("Updating the %s repository cache") %
                            repname.capitalize())
@@ -531,10 +533,13 @@ class Update(object):
         """
         self.endTask()
         _print = self.color_print
-        one = _print("{0}", num)
-        two = _print("{0}", max_num)
-        part = _(" ({current} of {maximum})").format(current=one,
-                                                     maximum=two)
+        if num and max_num:
+            one = _print("{0}", num)
+            two = _print("{0}", max_num)
+            part = _(" ({current} of {maximum})").format(current=one,
+                                                         maximum=two)
+        else:
+            part = ""
         _print = _print.foreground(Colors.LIGHT_RED)
 
         self.startTask(
@@ -751,6 +756,8 @@ class Update(object):
         """
         Установить флаг: есть обновления
         """
+        if self.clVars.Get('cl_update_autocheck_set') == 'off':
+            val = False
         UpdateInfo.set_update_ready(val)
         return True
 
@@ -794,7 +801,7 @@ class Update(object):
 
     def _display_error(self, error):
         lines_num = int(self.clVars.Get('update.cl_update_lines_limit'))
-        error = "\n".join(str(error).split('<br/>')[-lines_num:])
+        error = "<br/>".join(str(error).split('<br/>')[-lines_num:])
         self.printPre(self._emerge_translate(error))
 
     def emerge(self, param, *packages):
@@ -833,10 +840,12 @@ class Update(object):
         try:
             emerge = EmergeParser(EmergeCommand(["--depclean"],
                                         emerge_default_opts=deo))
+            outdated_kernel = False
             try:
                 emerge.question.action = lambda x: False
                 emerge.run()
                 if not emerge.uninstall_packages.list:
+                    UpdateInfo(self.clVars).outdated_kernel = False
                     return True
                 kernel_pkg = self.clVars.Get('cl_update_kernel_pkg')
                 if any(("%s-%s" % (x['CATEGORY/PN'], x['PVR'])) == kernel_pkg
@@ -850,6 +859,7 @@ class Update(object):
                     emerge.close()
                     emerge = None
                     if not pkglist:
+                        UpdateInfo(self.clVars).outdated_kernel = True
                         return True
                     emerge = EmergeParser(
                         EmergeCommand(pkglist,
@@ -857,6 +867,9 @@ class Update(object):
                                       emerge_default_opts=deo))
                     emerge.question.action = lambda x: False
                     emerge.run()
+                    outdated_kernel = True
+                else:
+                    outdated_kernel = False
                 self._display_remove_list(emerge)
             except EmergeError:
                 self._display_error(emerge.prepare_error)
@@ -864,6 +877,7 @@ class Update(object):
             if (self.askConfirm(
                     _("Would you like to unmerge these packages?")) != 'yes'):
                 return False
+            UpdateInfo(self.clVars).outdated_kernel = outdated_kernel
             self._startEmerging(emerge)
         finally:
             if emerge:
@@ -907,7 +921,7 @@ class Update(object):
         try:
             if not profile_dv:
                 raise UpdateError(
-                    _("Failed to use new profile. Try again."))
+                    _("Failed to use the new profile. Try again."))
             for var_name in ('cl_update_rep_rev',
                              'cl_update_rep_path',
                              'cl_update_rep_url',
