@@ -999,7 +999,7 @@ class VariableClUpdateAutocheckInterval(Variable):
 
     def choice(self):
         return [["6h",_("every six hours")],
-            ["12h",_("every twenty hours")],
+            ["12h",_("every twelve hours")],
             ["1d",_("daily")]]
 
 
